==> jsolution-ui-lib-0.0.26.tgz: package/src/components/Input/SearchDropdownInput/SearchDropdownInput.stories.tsx <==
import React from "react";
import { useState } from "react";
import SearchDropdownInput, { SearchDropdownInputProps } from "./index";
import { Meta, StoryObj } from "@storybook/react";
import { options, OptionTypes } from "../../Dropdown/DropdownOptionData";

const meta = {
  title: "component/Input/SearchDropdownInput",
  component: SearchDropdownInput,
  parameters: {
    layout: "centered",
    docs: {
      story: {
        height: "450px",
      },
    },
  },
  argTypes: {
    disable: { control: "boolean" },
    dropdownHeight: { control: "number" },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof SearchDropdownInput>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: SearchDropdownInputProps<OptionTypes>) => {
  const [inputValue, setInputValue] = useState("");
  const [selectedOption, setSelecteOption] = useState<OptionTypes>();

  const handleOnChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setInputValue(e.target.value);
  };

  const handleOnClick = (value: OptionTypes) => {
    setSelecteOption(value);
    setInputValue(value.name);
  };

  const handleOnError = () => {
    return false;
  };

  return (
    <SearchDropdownInput
      {...args}
      value={inputValue}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onChange={handleOnChange}
      onClick={handleOnClick}
      onError={handleOnError}
    />
  );
};

Default.args = {
  value: "",
  options: options,
  inputWidth: "300px",
  placeholder: "search",
};

export const Error: Story = (args: SearchDropdownInputProps<OptionTypes>) => {
  const [inputValue, setInputValue] = useState("");
  const [selectedOption, setSelecteOption] = useState<OptionTypes>();

  const handleOnChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setInputValue(e.target.value);
  };

  const handleOnClick = (value: OptionTypes) => {
    setSelecteOption(value);
    setInputValue(value.name);
  };

  const handleOnError = () => {
    return true;
  };

  return (
    <SearchDropdownInput
      {...args}
      value={inputValue}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onChange={handleOnChange}
      onClick={handleOnClick}
      onError={handleOnError}
    />
  );
};

Error.args = {
  value: "",
  options: options,
  placeholder: "search",
};

==> jsolution-ui-lib-0.0.33.tgz: package/src/components/Input/SearchDropdownInput/SearchDropdownInput.stories.tsx <==
import React from "react";
import { useState } from "react";
import SearchDropdownInput, { SearchDropdownInputProps } from "./index";
import { Meta, StoryObj } from "@storybook/react";
import { options, OptionTypes } from "../../Dropdown/DropdownOptionData";

const meta = {
  title: "component/Input/SearchDropdownInput",
  component: SearchDropdownInput,
  parameters: {
    layout: "centered",
    docs: {
      story: {
        height: "450px",
      },
    },
  },
  argTypes: {
    disable: { control: "boolean" },
    dropdownHeight: { control: "number" },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof SearchDropdownInput>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: SearchDropdownInputProps<OptionTypes>) => {
  const [inputValue, setInputValue] = useState("");
  const [selectedOption, setSelectedOption] = useState<OptionTypes>();

  const handleOnChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setInputValue(e.target.value);
  };

  const handleOnClick = (value: OptionTypes | undefined) => {
    if(!value) return;
    setSelectedOption(value);
    setInputValue(value.name);
  };

  const handleOnError = () => {
    return false;
  };

  return (
    <SearchDropdownInput
      {...args}
      value={inputValue}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onChange={handleOnChange}
      onClick={handleOnClick}
      onError={handleOnError}
    />
  );
};

Default.args = {
  value: "",
  options: options,
  inputWidth: "300px",
  placeholder: "search",
};

export const Error: Story = (args: SearchDropdownInputProps<OptionTypes>) => {
  const [inputValue, setInputValue] = useState("");
  const [selectedOption, setSelectedOption] = useState<OptionTypes>();

  const handleOnChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setInputValue(e.target.value);
  };

  const handleOnClick = (value: OptionTypes) => {
    setSelectedOption(value);
    setInputValue(value.name);
  };

  const handleOnError = () => {
    return true;
  };

  return (
    <SearchDropdownInput
      {...args}
      value={inputValue}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onChange={handleOnChange}
      onClick={handleOnClick}
      onError={handleOnError}
    />
  );
};

Error.args = {
  value: "",
  options: options,
  placeholder: "search",
};
